import React, { useEffect, useMemo, useState } from 'react'
import styles from './index.less'
import Search from './components/Search'
import TablePack from './components/TablePack'
import { GetAccountConfigInfo, GetAccountPageList, getStationListByUserID, GetTableJson } from '../../apis/process'

const TableRender = (props) => {

  const userID = window?.globalConfig?.userInfo?.OID || 1
  const { accountName } = props
  const [loading, setLoading] = useState(false)
  const [config, setConfig] = useState({ webShowFieldGroup: '', formJson: '' })
  const [dataSource, setDataSource] = useState([])

  const showField = useMemo(() => {
    const { webShowFieldGroup } = config
    return webShowFieldGroup.split(',').filter(v => v)
  }, [config])

  const getConfig = async () => {
    const { code, data } = await GetAccountConfigInfo(accountName)
    // if (code === 0) {
    //   setConfig(data)
    // }
    const res = await GetTableJson(accountName)
    if (code === 0 && res.code === 0) {
      setConfig({ ...data, formJson: res.data })
    }
  }

  const getDataSource = async (param) => {
    setLoading(true)
    let params = {
      userID: userID,
      accountName: '',
      direction: 'desc',
      timeField: '录入时间',
      pageIndex: 1,
      pageSize: 100,
      ...param,
    }
    const { code, data } = await GetAccountPageList(params)
    if (code === 0) {
      setDataSource(JSON.parse(data.jsonData))
    }
    setLoading(false)
  }

  const getData = () => {
    getConfig()
    getDataSource({ accountName })
  }

  useEffect(() => {
    getData()
  }, [])

  return (
    <div className={styles.tableRender}>
      <div className={styles.top}>
        <Search />
      </div>
      <div className={styles.bottom}>
        <TablePack
          loading={loading}
          showField={showField}
          formJson={config.formJson}
          dataSource={dataSource}
        />
      </div>
    </div>
  )

}

export default TableRender